.. module:: streamsets
.. _set_up:

Set Up
======
|

The following sections include explanations and examples of the usage and implementation of the StreamSets
Platform SDK for Python. They specifically pertain to the use of the SDK for environments, deployments,
engines and connections.

.. toctree::
   :maxdepth: 3
   :hidden:

   usage/set_up/environments/environments
   usage/set_up/deployments/deployments
   usage/set_up/connections/connections
